@@ -60,6 +60,7 @@ private:
 	void Fill_Label_Device_Info( bool clear = false );
 
 	void Add_Operation( Operation * operation, int index = -1 ) ;
+	bool valid_display_partition_ptr( const Partition * partition_ptr );
 	bool Merge_Operations( unsigned int first, unsigned int second );
 	void Refresh_Visual();
 	bool Quit_Check_Operations();
@@ -151,7 +152,7 @@ private:
 	void menu_help_contents();
 	void menu_help_about();
 
-	void on_partition_selected( const Partition & partition, bool src_is_treeview ) ;
+	void on_partition_selected( const Partition * partition_ptr, bool src_is_treeview );
 	void on_partition_activated() ;
 	void on_partition_popup_menu( unsigned int button, unsigned int time ) ;
 	
@@ -183,7 +184,11 @@ private:
 
 //private variables
 	unsigned int current_device ;
-	Partition selected_partition, copied_partition;
+	std::vector<Partition> display_partitions;  // Copy of current device's partitions with any pending
+	                                            // operations applied, as currently being shown in the GUI.
+	const Partition * selected_partition_ptr;   // Pointer to the selected partition.  (Alias to element
+	                                            // in Win_GParted::display_partitions[] vector).
+	Partition copied_partition;
 	std::vector<Device> devices;
 	std::vector<Operation *> operations;
 
