@@ -27,7 +27,7 @@ OperationCopy::OperationCopy( const Device & device,
 {
 	type = OPERATION_COPY ;
 
-	this ->device = device ;
+	this->device = device.get_copy_without_partitions();
 	this ->partition_original = partition_orig ;
 	this ->partition_new = partition_new ;
 	this ->partition_copied = partition_copied ;
