@@ -24,7 +24,7 @@ OperationDelete::OperationDelete( const Device & device, const Partition & parti
 {
 	type = OPERATION_DELETE ;
 
-	this ->device = device ;
+	this->device = device.get_copy_without_partitions();
 	this ->partition_original = partition_orig ;
 }
 	
