@@ -23,7 +23,7 @@
 namespace GParted
 {
 
-const Glib::ustring linux_swap::get_custom_text( CUSTOM_TEXT ttype, int index )
+const Glib::ustring linux_swap::get_custom_text( CUSTOM_TEXT ttype, int index ) const
 {
 	/*TO TRANSLATORS: these labels will be used in the partition menu */
 	static const Glib::ustring activate_text = _( "_Swapon" ) ;
